@@ -84,7 +84,7 @@ KAboutKdeDialog::KAboutKdeDialog(QWidget *parent)
     join->setText(
         i18n("<html>"
              "You do not have to be a software developer to be a member of the "
-             "KDE team. You can join the national teams that translate "
+             "KDE team. You can join the language teams that translate "
              "program interfaces. You can provide graphics, themes, sounds, and "
              "improved documentation. You decide!"
              "<br /><br />"
