@@ -93,17 +93,7 @@ void KActionCategory::unlistAction(QAction *action)
     //   This method is called from KActionCollection with an QObject formerly
     //   known as a QAction during _k_actionDestroyed(). So don't do fancy stuff
     //   here that needs a real QAction!
-
-    // Get the index for the action
-    int index = d->actions.indexOf(action);
-
-    // Action not found.
-    if (index == -1) {
-        return;
-    }
-
-    // Remove the action
-    d->actions.takeAt(index);
+    d->actions.erase(std::remove(d->actions.begin(), d->actions.end(), action), d->actions.end());
 }
 
 KActionCategoryPrivate::KActionCategoryPrivate(KActionCategory *host)
